EXPORTS
	??0CHttpTestBase@@QAE@XZ @ 1 NONAME ; CHttpTestBase::CHttpTestBase(void)
	??0CHttpTestTransBase@@QAE@XZ @ 2 NONAME ; CHttpTestTransBase::CHttpTestTransBase(void)
	??1CDummyServer@@UAE@XZ @ 3 NONAME ; CDummyServer::~CDummyServer(void)
	??1CHttpTestEngine@@UAE@XZ @ 4 NONAME ; CHttpTestEngine::~CHttpTestEngine(void)
	??1CScriptFile@@UAE@XZ @ 5 NONAME ; CScriptFile::~CScriptFile(void)
	??1CScriptSection@@UAE@XZ @ 6 NONAME ; CScriptSection::~CScriptSection(void)
	??1CScriptSectionItem@@UAE@XZ @ 7 NONAME ; CScriptSectionItem::~CScriptSectionItem(void)
	??RCHTTPTestUtils@@QAEXH@Z @ 8 NONAME ; void CHTTPTestUtils::operator()(int)
	??RCHTTPTestUtils@@QAEXHH@Z @ 9 NONAME ; void CHTTPTestUtils::operator()(int, int)
	?AddItemIfNotExistL@CScriptSection@@QAEXABVTDesC16@@0@Z @ 10 NONAME ; void CScriptSection::AddItemIfNotExistL(class TDesC16 const &, class TDesC16 const &)
	?AddItemL@CScriptSection@@QAEAAVCScriptSectionItem@@ABVTDesC16@@0@Z @ 11 NONAME ; class CScriptSectionItem & CScriptSection::AddItemL(class TDesC16 const &, class TDesC16 const &)
	?BeginTest@CHttpTestBase@@QAEXXZ @ 12 NONAME ; void CHttpTestBase::BeginTest(void)
	?CompleteOwnRequest@CHttpTestBase@@IAEXXZ @ 13 NONAME ; void CHttpTestBase::CompleteOwnRequest(void)
	?ConfigureTestSet@CHttpTestEngine@@QAEXV?$RPointerArray@VCHttpTestBase@@@@@Z @ 14 NONAME ; void CHttpTestEngine::ConfigureTestSet(class RPointerArray<class CHttpTestBase>)
	?Console@CHttpTestEngine@@QBEAAVCConsoleBase@@XZ @ 15 NONAME ; class CConsoleBase & CHttpTestEngine::Console(void) const
	?CopyLC@CScriptSection@@QAEPAV1@XZ @ 16 NONAME ; class CScriptSection * CScriptSection::CopyLC(void)
	?DeleteItemsL@CScriptSection@@QAEXABVTDesC16@@@Z @ 17 NONAME ; void CScriptSection::DeleteItemsL(class TDesC16 const &)
	?DoCancel@CDummyServer@@MAEXXZ @ 18 NONAME ; void CDummyServer::DoCancel(void)
	?DumpData@CHTTPTestUtils@@QAEXABVTDesC8@@H@Z @ 19 NONAME ; void CHTTPTestUtils::DumpData(class TDesC8 const &, int)
	?DumpRespHeaders@CHttpTestTransBase@@IAEXAAVRHTTPTransaction@@@Z @ 20 NONAME ; void CHttpTestTransBase::DumpRespHeaders(class RHTTPTransaction &)
	?DumpResponseBody@CHttpTestTransBase@@IAEXAAVRHTTPTransaction@@@Z @ 21 NONAME ; void CHttpTestTransBase::DumpResponseBody(class RHTTPTransaction &)
	?EndTest@CHTTPTestUtils@@QAEXH@Z @ 22 NONAME ; void CHTTPTestUtils::EndTest(int)
	?Error@CTestScheduler@@EBEXH@Z @ 23 NONAME ; void CTestScheduler::Error(int) const
	?ExpectedStatusCode@CHttpTestBase@@QAEHXZ @ 24 NONAME ; int CHttpTestBase::ExpectedStatusCode(void)
	?GetAnEntry@CHTTPTestUtils@@QAEXABVTDesC16@@AAVTDes16@@@Z @ 25 NONAME ; void CHTTPTestUtils::GetAnEntry(class TDesC16 const &, class TDes16 &)
	?GetNextDataPart@CHttpTestTransBase@@MAEHAAVTPtrC8@@@Z @ 26 NONAME ; int CHttpTestTransBase::GetNextDataPart(class TPtrC8 &)
	?GetNextWord@CScriptFile@@SAHAAVTLex16@@VTChar@@AAH@Z @ 27 NONAME ; int CScriptFile::GetNextWord(class TLex16 &, class TChar, int &)
	?GetNextWord@CScriptFile@@SAHAAVTLex16@@VTChar@@AAVTPtrC16@@@Z @ 28 NONAME ; int CScriptFile::GetNextWord(class TLex16 &, class TChar, class TPtrC16 &)
	?GetSelection@CHTTPTestUtils@@QAEHABVTDesC16@@0@Z @ 29 NONAME ; int CHTTPTestUtils::GetSelection(class TDesC16 const &, class TDesC16 const &)
	?HoldOpenConnectionL@CHTTPTestUtils@@SAXXZ @ 30 NONAME ; void CHTTPTestUtils::HoldOpenConnectionL(void)
	?InitCommsL@CHTTPTestUtils@@SAXXZ @ 31 NONAME ; void CHTTPTestUtils::InitCommsL(void)
	?Item@CScriptSection@@QAEPAVCScriptSectionItem@@ABVTDesC16@@@Z @ 32 NONAME ; class CScriptSectionItem * CScriptSection::Item(class TDesC16 const &)
	?ItemValue@CScriptFile@@QAEABVTDesC16@@ABV2@00@Z @ 33 NONAME ; class TDesC16 const & CScriptFile::ItemValue(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &)
	?ItemValue@CScriptFile@@QAEHABVTDesC16@@0H@Z @ 34 NONAME ; int CScriptFile::ItemValue(class TDesC16 const &, class TDesC16 const &, int)
	?ItemValue@CScriptSection@@QAEABVTDesC16@@ABV2@0@Z @ 35 NONAME ; class TDesC16 const & CScriptSection::ItemValue(class TDesC16 const &, class TDesC16 const &)
	?ItemValue@CScriptSection@@QAEHABVTDesC16@@H@Z @ 36 NONAME ; int CScriptSection::ItemValue(class TDesC16 const &, int)
	?ItemValueL@CScriptFile@@SAHAAVCHTTPTestUtils@@ABVTDesC16@@111H@Z @ 37 NONAME ; int CScriptFile::ItemValueL(class CHTTPTestUtils &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, int)
	?ItemValueLC@CScriptFile@@SAPAVHBufC16@@AAVCHTTPTestUtils@@ABVTDesC16@@1111@Z @ 38 NONAME ; class HBufC16 * CScriptFile::ItemValueLC(class CHTTPTestUtils &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &)
	?JustEndTest@CHTTPTestUtils@@QAEXXZ @ 39 NONAME ; void CHTTPTestUtils::JustEndTest(void)
	?JustStartTestL@CHTTPTestUtils@@QAEXABVTDesC16@@@Z @ 40 NONAME ; void CHTTPTestUtils::JustStartTestL(class TDesC16 const &)
	?ListenL@CDummyServer@@QAEXXZ @ 41 NONAME ; void CDummyServer::ListenL(void)
	?LogIt@CHTTPTestUtils@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 42 NONAME ; void CHTTPTestUtils::LogIt(class TRefByValue<class TDesC16 const >, ...)
	?MHFRunError@CHttpTestTransBase@@UAEHHVRHTTPTransaction@@ABVTHTTPEvent@@@Z @ 43 NONAME ; int CHttpTestTransBase::MHFRunError(int, class RHTTPTransaction, class THTTPEvent const &)
	?MHFRunL@CHttpTestTransBase@@UAEXVRHTTPTransaction@@ABVTHTTPEvent@@@Z @ 44 NONAME ; void CHttpTestTransBase::MHFRunL(class RHTTPTransaction, class THTTPEvent const &)
	?NewL@CDummyServer@@SAPAV1@HH@Z @ 45 NONAME ; class CDummyServer * CDummyServer::NewL(int, int)
	?NewL@CHTTPTestUtils@@SAPAV1@ABVTDesC16@@@Z @ 46 NONAME ; class CHTTPTestUtils * CHTTPTestUtils::NewL(class TDesC16 const &)
	?NewL@CHttpTestEngine@@SAPAV1@ABVTDesC16@@H@Z @ 47 NONAME ; class CHttpTestEngine * CHttpTestEngine::NewL(class TDesC16 const &, int)
	?NewL@CScriptFile@@SAPAV1@AAVCHTTPTestUtils@@ABVTDesC16@@1@Z @ 48 NONAME ; class CScriptFile * CScriptFile::NewL(class CHTTPTestUtils &, class TDesC16 const &, class TDesC16 const &)
	?NewL@CScriptFile@@SAPAV1@AAVCHTTPTestUtils@@ABVTDesC16@@@Z @ 49 NONAME ; class CScriptFile * CScriptFile::NewL(class CHTTPTestUtils &, class TDesC16 const &)
	?NewLC@CHTTPTestUtils@@SAPAV1@ABVTDesC16@@@Z @ 50 NONAME ; class CHTTPTestUtils * CHTTPTestUtils::NewLC(class TDesC16 const &)
	?NewLC@CScriptFile@@SAPAV1@AAVCHTTPTestUtils@@ABVTDesC16@@1@Z @ 51 NONAME ; class CScriptFile * CScriptFile::NewLC(class CHTTPTestUtils &, class TDesC16 const &, class TDesC16 const &)
	?NewLC@CScriptFile@@SAPAV1@AAVCHTTPTestUtils@@ABVTDesC16@@@Z @ 52 NONAME ; class CScriptFile * CScriptFile::NewLC(class CHTTPTestUtils &, class TDesC16 const &)
	?NewLC@CScriptSection@@SAPAV1@ABVTDesC16@@@Z @ 53 NONAME ; class CScriptSection * CScriptSection::NewLC(class TDesC16 const &)
	?NewLC@CScriptSection@@SAPAV1@ABVTDesC16@@AAV1@@Z @ 54 NONAME ; class CScriptSection * CScriptSection::NewLC(class TDesC16 const &, class CScriptSection &)
	?NewLC@CScriptSectionItem@@SAPAV1@AAVCScriptSection@@ABVTDesC16@@1@Z @ 55 NONAME ; class CScriptSectionItem * CScriptSectionItem::NewLC(class CScriptSection &, class TDesC16 const &, class TDesC16 const &)
	?NextStep@CHTTPTestUtils@@QAEXABVTDesC16@@@Z @ 56 NONAME ; void CHTTPTestUtils::NextStep(class TDesC16 const &)
	?OverallDataSize@CHttpTestTransBase@@MAEHXZ @ 57 NONAME ; int CHttpTestTransBase::OverallDataSize(void)
	?Overflow@CHTTPTestUtils@@EAEXAAVTDes16@@@Z @ 58 NONAME ; void CHTTPTestUtils::Overflow(class TDes16 &)
	?PressAnyKey@CHTTPTestUtils@@QAEXXZ @ 59 NONAME ; void CHTTPTestUtils::PressAnyKey(void)
	?PressAnyKey@CHttpTestEngine@@QAEXXZ @ 60 NONAME ; void CHttpTestEngine::PressAnyKey(void)
	?ReadFileLC@CHTTPTestUtils@@QAEPAVHBufC8@@ABVTDesC16@@@Z @ 61 NONAME ; class HBufC8 * CHTTPTestUtils::ReadFileLC(class TDesC16 const &)
	?ReadScriptL@CScriptFile@@QAEXABVTDesC16@@@Z @ 62 NONAME ; void CScriptFile::ReadScriptL(class TDesC16 const &)
	?ReleaseConnectionL@CHTTPTestUtils@@SAXXZ @ 63 NONAME ; void CHTTPTestUtils::ReleaseConnectionL(void)
	?ReleaseData@CHttpTestTransBase@@MAEXXZ @ 64 NONAME ; void CHttpTestTransBase::ReleaseData(void)
	?ReplaceItemL@CScriptSection@@QAEAAVCScriptSectionItem@@ABVTDesC16@@0@Z @ 65 NONAME ; class CScriptSectionItem & CScriptSection::ReplaceItemL(class TDesC16 const &, class TDesC16 const &)
	?ReplaceL@CScriptFile@@SAXABVTDesC16@@0AAPAVHBufC16@@@Z @ 66 NONAME ; void CScriptFile::ReplaceL(class TDesC16 const &, class TDesC16 const &, class HBufC16 * &)
	?ReplaceLC@CScriptFile@@SAPAVHBufC16@@ABVTDesC16@@00@Z @ 67 NONAME ; class HBufC16 * CScriptFile::ReplaceLC(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &)
	?Reset@CHttpTestTransBase@@UAEHXZ @ 68 NONAME ; int CHttpTestTransBase::Reset(void)
	?ResolveFile@CHTTPTestUtils@@QAEHABVTDesC16@@0AAVTParse@@@Z @ 69 NONAME ; int CHTTPTestUtils::ResolveFile(class TDesC16 const &, class TDesC16 const &, class TParse &)
	?RunError@CDummyServer@@MAEHH@Z @ 70 NONAME ; int CDummyServer::RunError(int)
	?RunError@CHttpTestBase@@MAEHH@Z @ 71 NONAME ; int CHttpTestBase::RunError(int)
	?RunL@CDummyServer@@MAEXXZ @ 72 NONAME ; void CDummyServer::RunL(void)
	?RunL@CHttpTestBase@@MAEXXZ @ 73 NONAME ; void CHttpTestBase::RunL(void)
	?Section@CScriptFile@@QAEPAVCScriptSection@@ABVTDesC16@@@Z @ 74 NONAME ; class CScriptSection * CScriptFile::Section(class TDesC16 const &)
	?SetCurrentStatusCode@CHttpTestEngine@@QAEXH@Z @ 75 NONAME ; void CHttpTestEngine::SetCurrentStatusCode(int)
	?SetScript@CHTTPTestUtils@@QAEXAAVRFile@@@Z @ 76 NONAME ; void CHTTPTestUtils::SetScript(class RFile &)
	?SetSilent@CHttpTestEngine@@QAEXH@Z @ 77 NONAME ; void CHttpTestEngine::SetSilent(int)
	?StartTestL@CHTTPTestUtils@@QAEXABVTDesC16@@@Z @ 78 NONAME ; void CHTTPTestUtils::StartTestL(class TDesC16 const &)
	?TestCompleted@CHttpTestEngine@@QAEXH@Z @ 79 NONAME ; void CHttpTestEngine::TestCompleted(int)
	?TestSummary@CHttpTestEngine@@QBEXAAH0@Z @ 80 NONAME ; void CHttpTestEngine::TestSummary(int &, int &) const
	?Utils@CHttpTestEngine@@QBEAAVCHTTPTestUtils@@XZ @ 81 NONAME ; class CHTTPTestUtils & CHttpTestEngine::Utils(void) const
	?ReplaceHostNameL@TSrvAddrVal@@SAPAVHBufC16@@ABVTDesC16@@PAVCScriptFile@@@Z @ 82 NONAME ; public: static class HBufC16 * __cdecl TSrvAddrVal::ReplaceHostNameL(class TDesC16 const &,class CScriptFile *)
	?ReplaceHostNameL@TSrvAddrVal@@SAPAVHBufC8@@ABVTDesC8@@PAVCScriptFile@@@Z @ 83 NONAME ; public: static class HBufC8 * __cdecl TSrvAddrVal::ReplaceHostNameL(class TDesC8 const &,class CScriptFile *)
	?LogUsing8BitDesL@TSrvAddrVal@@SAXPAVCHttpTestEngine@@ABVTDesC8@@@Z @ 84 NONAME ; public: static void __cdecl TSrvAddrVal::LogUsing8BitDesL(class CHttpTestEngine *,class TDesC8 const &)
	?CleanupFailedTestsArray@CHTTPTestUtils@@QAEXXZ @ 85 NONAME ; void CHTTPTestUtils::CleanupFailedTestsArray(void)
	?CreateFailedTestsArrayL@CHTTPTestUtils@@QAEXXZ @ 86 NONAME ; void CHTTPTestUtils::CreateFailedTestsArrayL(void)

